<?php

// Important: Turn off display errors on a production environment
ini_set("display_errors", false);
ini_set("log_errors", true);

// Set Timezone.
date_default_timezone_set('Asia/Kolkata');

// Register Composer auto loader.
require __DIR__ . '/php/vendor/autoload.php';

// Helper functions.
function sanitizeFormField($input) {
    return strip_tags(trim($input));
}

// Only process POST requests.
if ($_SERVER["REQUEST_METHOD"] == "POST") {

	// An array to hold validation errors.
    $errors = [];

    // Sanitize and validate the form fields.
    $name = sanitizeFormField($_POST['name']);
    if (empty($name)) {
        $errors['name'] = 'Name is required';
    } elseif (! preg_match( "/^[A-Za-z\s]+$/", $name)) {
    	$errors['name'] = 'Please enter a valid name';
    }

    $email = filter_var(trim($_POST["email"]), FILTER_SANITIZE_EMAIL);
    if(empty($email)) {
    	$errors['email'] = 'Email is required';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL) !== false) {
        $errors['email'] = 'Enter a valid email address';
    }

    $mobile = sanitizeFormField($_POST['mobile']);
    if(empty($mobile)) {
    	$errors['mobile'] = 'Mobile number is required';
    } elseif (! preg_match("/^[7-9][0-9]{9}$/", $mobile)) {
    	$errors['mobile'] = 'Enter a valid mobile number';
    }
   $message = sanitizeFormField($_POST['message']);
   
    // Check for form submission errors.
    if ( count($errors) > 0 ) {
        // Set a 400 (bad request) response code and exit.
        header('Content-Type: application/json');
        http_response_code(400);
        echo json_encode($errors);
        exit;
    }

    $data = [
    	'name' => $name,
    	'email'	=> $email,
      'mobile' => $mobile,
	  'message'=> $message,
    ];

    // Send Email to admin.
    $result = (new SendEmail)->toContactsAdmin($data);

    if($result == true) {
        // Set a 200 (okay) response code.
        http_response_code(200);
        echo "Thank for your interest, we'll get in touch with you shortly to assist you.";
    } else {
        // Set a 500 (internal server error) response code.
        http_response_code(500);
        echo "Something went wrong, couldn't send your message. Please submit again.";
    }

    // Send user auto responder mail.
    // (new SendEmail())->toUser($data);

    // Upload form data to Google Spreadsheet.
    putenv('GOOGLE_APPLICATION_CREDENTIALS=' . __DIR__ . '/Sweat By Swetha-963de76889c4.json');
    (new AddToGoogleSpreadSheet)->contacts([
        'name' => $name,
        'email' => $email,
        'mobile' => $mobile,
		'message'=> $message,
        'enquiredat' => date('d F, Y h:i:s a', time())
    ]);
} else {
    // Not a POST request, set a 403 (forbidden) response code.
    http_response_code(403);
    echo "There was a problem with your submission, please try again.";
}


